@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/download_binary_attr.php,v 1.13.2.3 2005/12/08 11:49:28 wurley Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/download_binary_attr.php,v 1.15.2.1 2007/12/26 09:26:32 wurley Exp $
 
 /**
  * @package phpLDAPadmin
@@ -25,9 +25,10 @@ $value_num = isset($_GET['value_num']) ? $_GET['value_num'] : null;
 if (! $ldapserver->dnExists($dn))
 	pla_error(sprintf(_('No such entry: %s'),pretty_print_dn($dn)));
 
-$search = $ldapserver->search(null,$dn,'(objectClass=*)',array($attr),'base',false,$config->GetValue('deref','view'));
+$search = $ldapserver->search(null,$dn,'(objectClass=*)',array($attr),'base',false,$_SESSION[APPCONFIG]->GetValue('deref','view'));
 
 # Dump the binary data to the browser
+if (ob_get_level()) ob_end_clean();
 header('Content-type: octet-stream');
 header("Content-disposition: attachment; filename=$attr");
 header('Expires: Mon, 26 Jul 1997 05:00:00 GMT');
