@@ -1,13 +1,15 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/header.php,v 1.24 2006/04/29 06:49:31 wurley Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/header.php,v 1.27.2.2 2008/01/27 11:57:38 wurley Exp $
 
 /**
  * @package phpLDAPadmin
  */
 
+require_once LIBDIR.'./common.php';
+
 /* We want to get $language into scope in case we were included
    from within a function */
-$language = isset($config) ? $language = $config->GetValue('appearance','language') : 'auto';
+$language = isset($_SESSION[APPCONFIG]) ? $language = $_SESSION[APPCONFIG]->GetValue('appearance','language') : 'auto';
 
 # text/xml won't work with MSIE, but is very useful for debugging xhtml code.
 # header('Content-type: text/xml; charset="UTF-8"');
@@ -24,12 +26,16 @@ echo "\n\n";
 
 echo '<head>';
 
-if (isset($config) && $pagetitle = $config->GetValue('appearance','page_title'))
+if (isset($_SESSION[APPCONFIG]) && $pagetitle = $_SESSION[APPCONFIG]->GetValue('appearance','page_title'))
 	printf('<title>phpLDAPadmin - %s</title>',$pagetitle);
 else
 	echo '<title>phpLDAPadmin</title>';
 
-printf('<link type="text/css" rel="stylesheet" href="%sstyle.css" media="screen" />',CSSDIR);
+if (isset($_SESSION[APPCONFIG]))
+	$css = $_SESSION[APPCONFIG]->GetValue('appearance','stylesheet');
+else
+	$css = 'style.css';
+printf('<link type="text/css" rel="stylesheet" href="%s%s" media="screen" />',CSSDIR,$css);
 
 if (isset($server_id)) {
 	$custom_file = get_custom_file($server_id,'style.css',CSSDIR);
@@ -40,13 +46,18 @@ if (isset($server_id)) {
 
 printf('<script type="text/javascript" src="%sentry_chooser.js"></script>',JSDIR);
 printf('<script type="text/javascript" src="%sie_png_work_around.js"></script>',JSDIR);
-printf('<script type="text/javascript" src="%ssearch_util.js"></script>',JSDIR);
 printf('<script type="text/javascript" src="%sgeneric_utils.js"></script>',JSDIR);
+printf('<script type="text/javascript" src="%sto_ascii.js"></script>',JSDIR);
+printf('<script type="text/javascript" src="%smodify_member.js"></script>',JSDIR);
 printf('<link type="text/css" rel="stylesheet" media="all" href="%s/jscalendar/calendar-blue.css" title="blue" />',JSDIR);
+
+echo "\n<!--\n";
 printf('<script type="text/javascript" src="%sjscalendar/calendar.js"></script>',JSDIR);
 printf('<script type="text/javascript" src="%sjscalendar/lang/calendar-en.js"></script>',JSDIR);
 printf('<script type="text/javascript" src="%sjscalendar/calendar-setup.js"></script>',JSDIR);
 printf('<script type="text/javascript" src="%sdate_selector.js"></script>',JSDIR);
+echo "\n-->\n";
+
 printf('<link type="text/css" rel="stylesheet" href="%s/phplayersmenu/layerstreemenu.css"></link>',JSDIR);
 
 if (isset($meta_refresh_variable))
