@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/index.php,v 1.49.2.4 2008/01/04 12:33:03 wurley Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/index.php,v 1.49.2.5 2008/01/12 10:01:28 wurley Exp $
 
 /**
  * @package phpLDAPadmin
@@ -50,7 +50,7 @@ else
 
 # Make sure this PHP install has gettext, we use it for language translation
 if (! extension_loaded('gettext'))
-	pla_error('<p>Your install of PHP appears to be missing GETTEXT support.</p><p>GETTEXT is used for language translation.</p><p>Please install GETTEXT support before using phpLDAPadmin.<br /><small>(Dont forget to restart your web server afterwards)</small></p>');
+	error('<p>Your install of PHP appears to be missing GETTEXT support.</p><p>GETTEXT is used for language translation.</p><p>Please install GETTEXT support before using phpLDAPadmin.<br /><small>(Dont forget to restart your web server afterwards)</small></p>','error',true);
 
 /**
  * Helper functions.
@@ -59,10 +59,10 @@ if (! extension_loaded('gettext'))
 if (isset($app['function_files']) && is_array($app['function_files']))
 	foreach ($app['function_files'] as $file_name ) {
 		if (! file_exists($file_name))
-			pla_error(sprintf('Fatal error: Required file "%s" does not exist.',$file_name));
+			error(sprintf('Fatal error: Required file "%s" does not exist.',$file_name),'error',true);
 
 		if (! is_readable($file_name))
-			pla_error(sprintf('Fatal error: Cannot read the file "%s", its permissions may be too strict.',$file_name));
+			error(sprintf('Fatal error: Cannot read the file "%s", its permissions may be too strict.',$file_name),'error',true);
 
 		ob_start();
 		require $file_name;
@@ -71,29 +71,10 @@ if (isset($app['function_files']) && is_array($app['function_files']))
 
 # Configuration File check
 if (! file_exists($app['config_file'])) {
-	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML Basic 1.0//EN"';
-	echo '"http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd">';
-
-	echo '<html>';
-	echo '<head>';
-	printf('<title>%s - %s</title>','phpLDAPadmin',pla_version());
-	echo '<link type="text/css" rel="stylesheet" href="css/style.css" />';
-	echo '</head>';
-
-	echo '<body>';
-	printf('<h3 class="title">Configure %s</h3>','phpLDAPadmin');
-	echo '<br /><br />';
-
-	echo '<center>';
-	printf(_('You need to configure %s. Edit the file "%s" to do so. An example config file is provided in "%s.example".'),'phpLDAPadmin',$app['config_file'],$app['config_file']);
-	echo '</center>';
-
-	echo '</body>';
-	echo '</html>';
-	die();
+	error(sprintf(_('You need to configure %s. Edit the file "%s" to do so. An example config file is provided in "%s.example".'),'phpLDAPadmin',$app['config_file'],$app['config_file']),'error',true);
 
 } elseif (! is_readable($app['config_file'])) {
-	pla_error(sprintf('Fatal error: Cannot read your configuration file "%s", its permissions may be too strict.',$app['config_file']));
+	error(sprintf('Fatal error: Cannot read your configuration file "%s", its permissions may be too strict.',$app['config_file']),'error',true);
 }
 
 # If our config file fails the sanity check, then stop now.
