@@ -22,112 +22,112 @@ class LayersMenuCommon
 * @access private
 * @var string
 */
-var $_packageName;
+public $_packageName;
 /**
 * The version of the package
 * @access private
 * @var string
 */
-var $version;
+public $version;
 /**
 * The copyright of the package
 * @access private
 * @var string
 */
-var $copyright;
+public $copyright;
 /**
 * The author of the package
 * @access private
 * @var string
 */
-var $author;
+public $author;
 
 /**
 * URL to be prepended to the menu hrefs
 * @access private
 * @var string
 */
-var $prependedUrl = '';
+public $prependedUrl = '';
 /**
 * Do you want that code execution halts on error?
 * @access private
 * @var string
 */
-var $haltOnError = 'yes';
+public $haltOnError = 'yes';
 
 /**
 * The base directory where the package is installed
 * @access private
 * @var string
 */
-var $dirroot;
+public $dirroot;
 /**
 * The "libjs" directory of the package
 * @access private
 * @var string
 */
-var $libjsdir;
+public $libjsdir;
 /**
 * The directory where images related to the menu can be found
 * @access private
 * @var string
 */
-var $imgdir;
+public $imgdir;
 /**
 * The http path corresponding to imgdir
 * @access private
 * @var string
 */
-var $imgwww;
+public $imgwww;
 /**
 * The directory where icons of menu items can be found
 * @access private
 * @var string
 */
-var $icondir;
+public $icondir;
 /**
 * The http path corresponding to icondir
 * @access private
 * @var string
 */
-var $iconwww;
+public $iconwww;
 /**
 * This array may contain width and height of all icons
 * @access private
 * @var integer
 */
-var $iconsize = array();
+public $iconsize = array();
 /**
 * If this var is false, width and height of icons have to be detected; if this var is true, width and height of icons are not detected and are retrieved from the iconsize array
 * @access private
 * @var boolean
 */
-var $issetIconsize = false;
+public $issetIconsize = false;
 /**
 * The directory where templates can be found
 * @access private
 * @var string
 */
-var $tpldir;
+public $tpldir;
 /**
 * The string containing the menu structure
 * @access private
 * @var string
 */
-var $menuStructure;
+public $menuStructure;
 
 /**
 * It counts nodes for all menus
 * @access private
 * @var integer
 */
-var $_nodesCount;
+public $_nodesCount;
 /**
 * A multi-dimensional array to store informations for each menu entry
 * @access private
 * @var array
 */
-var $tree;
+public $tree;
 /**
 * A multi-dimensional array used only with the DB support; for each $menu_name, it stores the $cnt associated to each item id
 *
@@ -138,56 +138,56 @@ var $tree;
 * @access private
 * @var array
 */
-var $treecnt;
+public $treecnt;
 /**
 * The maximum hierarchical level of menu items
 * @access private
 * @var integer
 */
-var $_maxLevel;
+public $_maxLevel;
 /**
 * An array that counts the number of first level items for each menu
 * @access private
 * @var array
 */
-var $_firstLevelCnt;
+public $_firstLevelCnt;
 /**
 * An array containing the number identifying the first item of each menu
 * @access private
 * @var array
 */
-var $_firstItem;
+public $_firstItem;
 /**
 * An array containing the number identifying the last item of each menu
 * @access private
 * @var array
 */
-var $_lastItem;
+public $_lastItem;
 
 /**
 * Data Source Name: the connection string for PEAR DB
 * @access private
 * @var string
 */
-var $dsn = 'pgsql://dbuser:dbpass@dbhost/dbname';
+public $dsn = 'pgsql://dbuser:dbpass@dbhost/dbname';
 /**
 * DB connections are either persistent or not persistent
 * @access private
 * @var boolean
 */
-var $persistent = false;
+public $persistent = false;
 /**
 * Name of the table storing data describing the menu
 * @access private
 * @var string
 */
-var $tableName = 'phplayersmenu';
+public $tableName = 'phplayersmenu';
 /**
 * Name of the i18n table corresponding to $tableName
 * @access private
 * @var string
 */
-var $tableName_i18n = 'phplayersmenu_i18n';
+public $tableName_i18n = 'phplayersmenu_i18n';
 /**
 * Names of fields of the table storing data describing the menu
 *
@@ -197,7 +197,7 @@ var $tableName_i18n = 'phplayersmenu_i18n';
 * @access private
 * @var array
 */
-var $tableFields = array(
+public $tableFields = array(
 	'id'		=> 'id',
 	'parent_id'	=> 'parent_id',
 	'text'		=> 'text',
@@ -213,7 +213,7 @@ var $tableFields = array(
 * @access private
 * @var array
 */
-var $tableFields_i18n = array(
+public $tableFields_i18n = array(
 	'language'	=> 'language',
 	'id'		=> 'id',
 	'text'		=> 'text',
@@ -224,7 +224,7 @@ var $tableFields_i18n = array(
 * @access private
 * @var array
 */
-var $_tmpArray = array();
+public $_tmpArray = array();
 
 /**
 * The constructor method; it initializates the menu system
@@ -315,7 +315,9 @@ function setLibjsdir($libjsdir)
 	if ($libjsdir != '' && substr($libjsdir, -1) != '/') {
 		$libjsdir .= '/';
 	}
-	if ($libjsdir == '' || substr($libjsdir, 0, 1) != '/') {
+	if ($libjsdir == '' || (substr($libjsdir, 0, 1) != '/' && substr($libjsdir, 1, 1) != ':')) {
+		// libjsdir != /.../...
+		// and libjsdir != C:\...\...
 		$foobar = strpos($libjsdir, $this->dirroot);
 		if ($foobar === false || $foobar != 0) {
 			$libjsdir = $this->dirroot . $libjsdir;
@@ -339,7 +341,7 @@ function setImgdir($imgdir)
 	if ($imgdir != '' && substr($imgdir, -1) != '/') {
 		$imgdir .= '/';
 	}
-	if ($imgdir == '' || substr($imgdir, 0, 1) != '/') {
+	if ($imgdir == '' || (substr($imgdir, 0, 1) != '/' && substr($imgdir, 1, 1) != ':')) {
 		$foobar = strpos($imgdir, $this->dirroot);
 		if ($foobar === false || $foobar != 0) {
 			$imgdir = $this->dirroot . $imgdir;
@@ -376,7 +378,7 @@ function setIcondir($icondir)
 	if ($icondir != '' && substr($icondir, -1) != '/') {
 		$icondir .= '/';
 	}
-	if ($icondir == '' || substr($icondir, 0, 1) != '/') {
+	if ($icondir == '' || (substr($icondir, 0, 1) != '/' && substr($icondir, 1, 1) != ':')) {
 		$foobar = strpos($icondir, $this->dirroot);
 		if ($foobar === false || $foobar != 0) {
 			$icondir = $this->dirroot . $icondir;
@@ -437,7 +439,7 @@ function setTpldirCommon($tpldir)
 	if ($tpldir != '' && substr($tpldir, -1) != '/') {
 		$tpldir .= '/';
 	}
-	if ($tpldir == '' || substr($tpldir, 0, 1) != '/') {
+	if ($tpldir == '' || (substr($tpldir, 0, 1) != '/' && substr($tpldir, 1, 1) != ':')) {
 		$foobar = strpos($tpldir, $this->dirroot);
 		if ($foobar === false || $foobar != 0) {
 			$tpldir = $this->dirroot . $tpldir;
