@@ -1,17 +1,16 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/mass_delete.php,v 1.16 2005/12/17 00:00:11 wurley Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/htdocs/mass_delete.php,v 1.17.2.2 2008/01/13 05:37:01 wurley Exp $
 
 /**
  * Enables user to mass delete multiple entries using checkboxes.
  *
- * Variables that come in via common.php
- *  - server_id
  * Variables that come in as GET vars:
- *  - mass_delete - an array of DNs to delete in this form:
- *      Array (
- *          [o=myorg,dc=example,dc=com] => on
- *          [cn=bob,dc=example,dc=com] => on
- *          etc.
+ *	- mass_delete - an array of DNs to delete in this form:
+ *		Array (
+ *			[o=myorg,dc=example,dc=com] => on
+ *			[cn=bob,dc=example,dc=com] => on
+ *		)
+ *		etc.
  *
  * @package phpLDAPadmin
  */
@@ -22,8 +21,9 @@ require './common.php';
 
 if( $ldapserver->isReadOnly() )
 	pla_error(_('Unable to delete, server is in READY-ONLY mode.'));
-if( ! $ldapserver->haveAuthInfo())
-	pla_error(_('Not enough information to login to server. Please check your configuration.'));
+
+if (! $_SESSION[APPCONFIG]->isCommandAvailable('entry_delete', 'mass_delete'))
+	pla_error(sprintf('%s%s %s',_('This operation is not permitted by the configuration'),_(':'),_('delete mass entries')));
 
 $confirmed = isset($_POST['confirmed']) ? true : false;
 isset($_POST['mass_delete']) or
@@ -37,9 +37,6 @@ is_array($mass_delete) or
 $ldapserver->isMassDeleteEnabled() or
 	pla_error(_('Mass deletion is not enabled. Please enable it in config.php before proceeding.'));
 
-require './header.php';
-
-echo '<body>';
 printf('<h3 class="title">%s</h3>',_('Mass Deleting'));
 
 if ($confirmed == true) {
@@ -56,19 +53,18 @@ if ($confirmed == true) {
 	if (count($mass_delete) == 0) {
 		echo '<br />';
 		printf('<center>%s</center>',_('You did not select any entries to delete.'));
-		die();
+		return;
 	}
 
 	// @todo: Should sort these entries, so that they are deleted in order, if a user selects children.
 	foreach ($mass_delete as $dn => $junk) {
 		printf(_('Deleting %s'),htmlspecialchars($dn));
-		flush();
 
 		if(run_hook('pre_entry_delete',array('server_id'=>$ldapserver->server_id,'dn'=>$dn))) {
 			$success = $ldapserver->delete($dn);
 
 			if ($success) {
-		                run_hook('post_entry_delete',array('server_id'=>$ldapserver->server_id,'dn'=>$dn));
+				run_hook('post_entry_delete',array('server_id'=>$ldapserver->server_id,'dn'=>$dn));
 
 				printf(' <span style="color:green">%s</span>.<br />',_('Success'));
 				$successfully_delete_dns[] = $dn;
@@ -78,8 +74,6 @@ if ($confirmed == true) {
 				$failed_dns[] = $dn;
 			}
 		}
-
-		flush();
 	}
 
 	echo '<blockquote>';
@@ -93,8 +87,6 @@ if ($confirmed == true) {
 	else
 		printf('<span style="color: green; font-weight: bold;">%s</span>',_('All entries deleted successfully.'));
 
-	echo '<script language="javascript">parent.left_frame.location.reload();</script>';
-
 } else {
 	$n = count($mass_delete);
 	printf('<h3 class="subtitle">'._('Confirm mass delete of %s entries on server %s').'</h3>',$n,$ldapserver->name);
@@ -103,7 +95,7 @@ if ($confirmed == true) {
 	printf(_('Do you really want to delete %s %s %s'),
 		($n == 1? _('this') : _('these')),$n,($n == 1 ? _('entry') : _('entries')));
 
-	echo '<form action="mass_delete.php" method="post">';
+	echo '<form action="cmd.php?cmd=mass_delete" method="post">';
 	echo '<input type="hidden" name="confirmed" value="true" />';
 	printf('<input type="hidden" name="server_id" value="%s" />',$ldapserver->server_id);
 
@@ -112,7 +104,7 @@ if ($confirmed == true) {
 		printf('<input type="hidden" name="mass_delete[%s]" value="on" /><li>%s</li>',htmlspecialchars($dn),htmlspecialchars($dn));
 	echo '</ol></td></tr></table>';
 
-	printf('<input class="scary" type="submit" value="%s" /></center>',_('Yes, delete!'));
+	printf('<input type="submit" value="%s" /></center>',_('Yes, delete!'));
 	echo '</form>';
 }
 ?>
