@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/phpldapadmin/phpldapadmin/lib/search_form_advanced.php,v 1.26.2.1 2007/12/26 09:26:33 wurley Exp $
+// $Header: /cvsroot/phpldapadmin/phpldapadmin/lib/search_form_advanced.php,v 1.26.2.2 2008/01/13 05:37:02 wurley Exp $
 
 /**
  * @package phpLDAPadmin
@@ -22,14 +22,15 @@ function focus_filter() {
 }
 </script>
 
-<form action="cmd.php" method="get" class="search" name="advanced_search_form">
+<h3 class="title"><?php echo _('Advanced Search Form'); ?></h3>
+<br />
+<form action="cmd.php" name="advanced_search_form">
 <input type="hidden" name="cmd" value="search" />
 <input type="hidden" name="search" value="true" />
 <input type="hidden" name="form" value="advanced" />
 <input type="hidden" name="format" value="<?php echo $entry['format']; ?>" />
 
-<table class="search" border=0>
-	<tr><td class="title" colspan=2><?php echo _('Advanced Search Form'); ?></td></tr>
+<table class="forminput" border=0>
 
 <?php
 	$ss = $_SESSION[APPCONFIG]->isCommandAvailable('search', 'simple_search');
@@ -57,26 +58,26 @@ function focus_filter() {
 
 	<tr><td colspan=2>&nbsp;</td></tr>
 
-	<tr><td><small><?php echo _('Server'); ?></small></td><td><?php echo $server_menu_html; ?></td></tr>
+	<tr><td><?php echo _('Server'); ?></td><td><?php echo $server_menu_html; ?></td></tr>
 
 	<tr>
-		<td><small><?php echo _('Base DN'); ?></small></td>
+		<td><?php echo _('Base DN'); ?></td>
 		<td><input type="text" name="base_dn" value="<?php echo count($base_dns) == 1 ? $base_dns[0] : '' ?>" style="width: 200px" id="base_dn" />
 
 <?php
 draw_chooser_link('advanced_search_form.base_dn');
 
 if (isset($entry['base_dn']['invalid']) && $entry['base_dn']['invalid'])
-	printf('<small style="color:red; white-space: nowrap">%s</small>',_('This is not a valid DN.'));
+	printf('<tr><td>&nbsp;</td><td><small style="color:red; white-space: nowrap">%s</small></td></tr>',_('This is not a valid DN.'));
 
 if (isset($entry['base_dn']['exist']) && $entry['base_dn']['exist'])
-	printf('<small style="color:red; white-space: nowrap">%s</small>',_('This entry does not exist.'));
+	printf('<tr><td>&nbsp;</td><td><small style="color:red; white-space: nowrap">%s</small></td></tr>',_('This entry does not exist.'));
 ?>
 		</td>
 	</tr>
 
 	<tr>
-		<td><small><acronym title="<?php echo _('The scope in which to search'); ?>"><?php echo _('Search Scope'); ?></acronym></small></td>
+		<td><acronym title="<?php echo _('The scope in which to search'); ?>"><?php echo _('Search Scope'); ?></acronym></td>
 		<td>
 			<select name="scope" style="width: 200px">
 				<option<?php echo $entry['scope']=='sub'?' selected':''; ?> value="sub">
@@ -93,14 +94,14 @@ if (isset($entry['base_dn']['exist']) && $entry['base_dn']['exist'])
 	</tr>
 
 	<tr>
-		<td><small><acronym title="<?php echo htmlspecialchars(_('Standard LDAP search filter. Example: (&(sn=Smith)(givenname=David))')); ?>">
-			<?php echo _('Search Filter'); ?></acronym></small></td>
+		<td><acronym title="<?php echo htmlspecialchars(_('Standard LDAP search filter. Example: (&(sn=Smith)(givenname=David))')); ?>">
+			<?php echo _('Search Filter'); ?></acronym></td>
 		<td><input type="text" name="filter" id="filter" style="width: 200px" value="<?php echo $entry['filter']['clean'] ? htmlspecialchars($entry['filter']['clean']) : 'objectClass=*'; ?>" /></td>
 	</tr>
 
 	<tr>
-		<td><small><acronym title="<?php echo _('A list of attributes to display in the results (comma-separated)'); ?>">
-			<?php echo _('Show Attributtes'); ?></acronym></small></td>
+		<td><acronym title="<?php echo _('A list of attributes to display in the results (comma-separated)'); ?>">
+			<?php echo _('Show Attributtes'); ?></acronym></td>
 
 		 <td><input type="text" name="display_attrs" style="width: 200px" value="<?php
 			echo $entry['display']['string'] ? htmlspecialchars($entry['display']['string']) :
@@ -108,7 +109,7 @@ if (isset($entry['base_dn']['exist']) && $entry['base_dn']['exist'])
 	</tr>
 
 	<tr>
-		<td><small><acronym title="<?php echo htmlspecialchars(_('Order by').'...'); ?>"><?php echo _('Order by'); ?></acronym></small></td>
+		<td><acronym title="<?php echo htmlspecialchars(_('Order by').'...'); ?>"><?php echo _('Order by'); ?></acronym></td>
 		<td><input type="text" name="orderby" id="orderby" style="width: 200px" value="<?php echo htmlspecialchars($entry['orderby']['string']) ?>" /></td>
 	</tr>
 
